@@ -4,7 +4,7 @@ use warnings FATAL => 'all';
 
 package namespace::local;
 
-our $VERSION = '0.07_01';
+our $VERSION = '0.07_02';
 
 =head1 NAME
 
@@ -110,7 +110,7 @@ The following symbols are not touched by this module, to avoid breaking things:
 
 =item * Arrays: C<@CARP_NOT>, C<@EXPORT>, C<@EXPORT_OK>, C<@ISA>;
 
-=item * Scalars: C<$AUTOLOAD>, C<$a>, C<$b>;
+=item * Scalars: C<$AUTOLOAD>, C<$DESTROY>*, C<$a>, C<$b>;
 
 =item * Files: C<DATA>, C<STDERR>, C<STDIN>, C<STDOUT>;
 
@@ -118,6 +118,9 @@ The following symbols are not touched by this module, to avoid breaking things:
 
 =back
 
+*C<$DESTROY> is not a special variable, however,
+changing it was causing segfault in Perl 5.10.1
+
 This list is likely incomplete, and may grow in the future.
 
 =head1 METHOD/FUNCTIONS
@@ -192,6 +195,9 @@ use Carp;
 use Scalar::Util qw(refaddr);
 our @CARP_NOT = qw(namespace::local);
 
+# TODO need better env parsing...
+use constant DEBUG => ( lc ($ENV{PERL_NAMESPACE_LOCAL} || '' ) eq 'debug' ? 1 : 0 );
+
 ### Setup methods
 
 # requires caller => [caller] argument
@@ -210,7 +216,7 @@ sub new {
     $opt{touch_not}{$_}{ARRAY}++  for qw( CARP_NOT EXPORT EXPORT_OK ISA );
     $opt{touch_not}{$_}{CODE}++   for qw( AUTOLOAD DESTROY import );
     $opt{touch_not}{$_}{IO}++     for qw( DATA STDERR STDIN STDOUT );
-    $opt{touch_not}{$_}{SCALAR}++ for qw( AUTOLOAD a b );
+    $opt{touch_not}{$_}{SCALAR}++ for qw( AUTOLOAD DESTROY a b );
 
     return bless \%opt, $class;
 };
@@ -369,8 +375,12 @@ sub replace_symbols {
 
     # create a plan for change
     my $diff = $self->table_diff( $old_table, $table );
+    return unless keys %$diff;
 
     # apply change
+    $self->message( "package $self->{target} to be altered: ".dump_table($diff) )
+        if DEBUG;
+
     $self->write_symbols( $diff );
 };
 
@@ -416,8 +426,8 @@ sub table_diff {
         };
 
         if ($diff->{$name}) {
-            # now if we cannot avoid overwriting,
-            # make sure to copy over ALL skipped values for this name
+            # if we cannot avoid overwriting,
+            # make sure to copy ALL skipped values we know of
             $diff->{$name}{$_} = $old->{$_} for keys %$skip;
         };
     };
@@ -505,6 +515,30 @@ sub write_symbols {
     };
 };
 
+### Logging
+
+sub dump_table {
+    my $table = shift;
+
+    my @out;
+    foreach my $name( sort keys %$table ) {
+        my $glob = $table->{$name};
+        foreach my $type( sort keys %$glob ) {
+            push @out, "*$name\{$type\}=".($glob->{$type} || 'undef');
+        };
+    };
+
+    return join ", ", @out;
+};
+
+
+sub message {
+    my ($self, $msg) = @_;
+
+    $msg =~ s/\n$//s;
+    carp "$msg via namespace::local from $self->{origin}";
+};
+
 sub _croak {
     croak ("namespace::local: ".shift);
 };
